cataclysm::session

Struct Session

source
pub struct Session { /* private fields */ }
Working sessions, but not finished

Implementations

source

impl Session

source

pub fn new_with_values<A: 'static + SessionCreator>( session_creator: A, values: HashMap<String, String>, ) -> Session

Creates a new session

source

impl Session

source

pub fn set<A: Into<String>, B: Into<String>>(&mut self, key: A, value: B)

Sets a new value in the session

source

pub fn get<T: AsRef<str>>(&self, key: T) -> Option<&String>

Retrieves a value from the session

source

pub fn clear(&mut self)

Clears all values in the session

source

pub fn apply(self, req: Response) -> Response

Applies all the changes of the session to the response.

It is not the most elegant solution, but soon a new one will be worked out to apply the session changes to the response (probably using layers).